"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .discountfixedonceforeverdurationcreate import (
    DiscountFixedOnceForeverDurationCreate,
    DiscountFixedOnceForeverDurationCreateTypedDict,
)
from .discountfixedrepeatdurationcreate import (
    DiscountFixedRepeatDurationCreate,
    DiscountFixedRepeatDurationCreateTypedDict,
)
from .discountpercentageonceforeverdurationcreate import (
    DiscountPercentageOnceForeverDurationCreate,
    DiscountPercentageOnceForeverDurationCreateTypedDict,
)
from .discountpercentagerepeatdurationcreate import (
    DiscountPercentageRepeatDurationCreate,
    DiscountPercentageRepeatDurationCreateTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


DiscountCreateTypedDict = TypeAliasType(
    "DiscountCreateTypedDict",
    Union[
        DiscountPercentageOnceForeverDurationCreateTypedDict,
        DiscountFixedOnceForeverDurationCreateTypedDict,
        DiscountPercentageRepeatDurationCreateTypedDict,
        DiscountFixedRepeatDurationCreateTypedDict,
    ],
)


DiscountCreate = TypeAliasType(
    "DiscountCreate",
    Union[
        DiscountPercentageOnceForeverDurationCreate,
        DiscountFixedOnceForeverDurationCreate,
        DiscountPercentageRepeatDurationCreate,
        DiscountFixedRepeatDurationCreate,
    ],
)
