"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class BenefitDiscordCreatePropertiesTypedDict(TypedDict):
    r"""Properties to create a benefit of type `discord`."""

    guild_token: str
    role_id: str
    r"""The ID of the Discord role to grant."""


class BenefitDiscordCreateProperties(BaseModel):
    r"""Properties to create a benefit of type `discord`."""

    guild_token: str

    role_id: str
    r"""The ID of the Discord role to grant."""
