"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class CurrencyAmountTypedDict(TypedDict):
    currency: str
    r"""Three letter currency code (eg: USD)"""
    amount: int
    r"""Amount in the currencies smallest unit (cents if currency is USD)"""


class CurrencyAmount(BaseModel):
    currency: str
    r"""Three letter currency code (eg: USD)"""

    amount: int
    r"""Amount in the currencies smallest unit (cents if currency is USD)"""
