"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class ArticleReceiversTypedDict(TypedDict):
    free_subscribers: int
    premium_subscribers: int
    organization_members: int


class ArticleReceivers(BaseModel):
    free_subscribers: int

    premium_subscribers: int

    organization_members: int
