"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class AttachedCustomFieldCreateTypedDict(TypedDict):
    r"""Schema to attach a custom field to a resource."""

    custom_field_id: str
    r"""ID of the custom field to attach."""
    required: bool
    r"""Whether the value is required for this custom field."""


class AttachedCustomFieldCreate(BaseModel):
    r"""Schema to attach a custom field to a resource."""

    custom_field_id: str
    r"""ID of the custom field to attach."""

    required: bool
    r"""Whether the value is required for this custom field."""
