"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class ArticlesExportRequestTypedDict(TypedDict):
    organization_id: str


class ArticlesExportRequest(BaseModel):
    organization_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
