"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .oauth2clientconfigurationupdate import (
    OAuth2ClientConfigurationUpdate,
    OAuth2ClientConfigurationUpdateTypedDict,
)
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class Oauth2ClientsOauth2UpdateClientRequestTypedDict(TypedDict):
    client_id: str
    o_auth2_client_configuration_update: OAuth2ClientConfigurationUpdateTypedDict


class Oauth2ClientsOauth2UpdateClientRequest(BaseModel):
    client_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    o_auth2_client_configuration_update: Annotated[
        OAuth2ClientConfigurationUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
