"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class CheckoutStatus(str, Enum):
    OPEN = "open"
    EXPIRED = "expired"
    CONFIRMED = "confirmed"
    SUCCEEDED = "succeeded"
    FAILED = "failed"
