"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .checkoutlinkpricecreate import (
    CheckoutLinkPriceCreate,
    CheckoutLinkPriceCreateTypedDict,
)
from .checkoutlinkproductcreate import (
    CheckoutLinkProductCreate,
    CheckoutLinkProductCreateTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


CheckoutLinkCreateTypedDict = TypeAliasType(
    "CheckoutLinkCreateTypedDict",
    Union[CheckoutLinkProductCreateTypedDict, CheckoutLinkPriceCreateTypedDict],
)


CheckoutLinkCreate = TypeAliasType(
    "CheckoutLinkCreate", Union[CheckoutLinkProductCreate, CheckoutLinkPriceCreate]
)
