"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class Timeframe(str, Enum):
    YEAR = "year"
    MONTH = "month"
    DAY = "day"


class BenefitLicenseKeyExpirationPropertiesTypedDict(TypedDict):
    ttl: int
    timeframe: Timeframe


class BenefitLicenseKeyExpirationProperties(BaseModel):
    ttl: int

    timeframe: Timeframe
