"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PledgeState(str, Enum):
    INITIATED = "initiated"
    CREATED = "created"
    PENDING = "pending"
    REFUNDED = "refunded"
    DISPUTED = "disputed"
    CHARGE_DISPUTED = "charge_disputed"
    CANCELLED = "cancelled"
