"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .useradvertisementcampaign import (
    UserAdvertisementCampaign,
    UserAdvertisementCampaignTypedDict,
)
from polar_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListResourceUserAdvertisementCampaignTypedDict(TypedDict):
    items: List[UserAdvertisementCampaignTypedDict]
    pagination: PaginationTypedDict


class ListResourceUserAdvertisementCampaign(BaseModel):
    items: List[UserAdvertisementCampaign]

    pagination: Pagination
