"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CustomFieldDatePropertiesTypedDict(TypedDict):
    form_label: NotRequired[str]
    form_help_text: NotRequired[str]
    form_placeholder: NotRequired[str]
    ge: NotRequired[int]
    le: NotRequired[int]


class CustomFieldDateProperties(BaseModel):
    form_label: Optional[str] = None

    form_help_text: Optional[str] = None

    form_placeholder: Optional[str] = None

    ge: Optional[int] = None

    le: Optional[int] = None
