"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from polar_sdk.downloadables import Downloadables
from polar_sdk.polar_advertisements import PolarAdvertisements
from polar_sdk.polar_benefits import PolarBenefits
from polar_sdk.polar_license_keys import PolarLicenseKeys
from polar_sdk.polar_orders import PolarOrders
from polar_sdk.polar_subscriptions import PolarSubscriptions


class Users(BaseSDK):
    benefits: PolarBenefits
    orders: PolarOrders
    subscriptions: PolarSubscriptions
    advertisements: PolarAdvertisements
    downloadables: Downloadables
    license_keys: PolarLicenseKeys

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.benefits = PolarBenefits(self.sdk_configuration)
        self.orders = PolarOrders(self.sdk_configuration)
        self.subscriptions = PolarSubscriptions(self.sdk_configuration)
        self.advertisements = PolarAdvertisements(self.sdk_configuration)
        self.downloadables = Downloadables(self.sdk_configuration)
        self.license_keys = PolarLicenseKeys(self.sdk_configuration)
