"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .benefitads import BenefitAds, BenefitAdsTypedDict
from .benefitarticles import BenefitArticles, BenefitArticlesTypedDict
from .benefitcustom import BenefitCustom, BenefitCustomTypedDict
from .benefitdiscord import BenefitDiscord, BenefitDiscordTypedDict
from .benefitdownloadables import BenefitDownloadables, BenefitDownloadablesTypedDict
from .benefitgithubrepository import (
    BenefitGitHubRepository,
    BenefitGitHubRepositoryTypedDict,
)
from .benefitlicensekeys import BenefitLicenseKeys, BenefitLicenseKeysTypedDict
from typing import Union
from typing_extensions import TypeAliasType


BenefitTypedDict = TypeAliasType(
    "BenefitTypedDict",
    Union[
        BenefitArticlesTypedDict,
        BenefitAdsTypedDict,
        BenefitDiscordTypedDict,
        BenefitGitHubRepositoryTypedDict,
        BenefitDownloadablesTypedDict,
        BenefitLicenseKeysTypedDict,
        BenefitCustomTypedDict,
    ],
)


Benefit = TypeAliasType(
    "Benefit",
    Union[
        BenefitArticles,
        BenefitAds,
        BenefitDiscord,
        BenefitGitHubRepository,
        BenefitDownloadables,
        BenefitLicenseKeys,
        BenefitCustom,
    ],
)
