"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .listresource_oauth2client_ import (
    ListResourceOAuth2Client,
    ListResourceOAuth2ClientTypedDict,
)
from polar_sdk.types import BaseModel
from polar_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import Callable, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Oauth2ClientsListRequestTypedDict(TypedDict):
    page: NotRequired[int]
    r"""Page number, defaults to 1."""
    limit: NotRequired[int]
    r"""Size of a page, defaults to 10. Maximum is 100."""


class Oauth2ClientsListRequest(BaseModel):
    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1
    r"""Page number, defaults to 1."""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 10
    r"""Size of a page, defaults to 10. Maximum is 100."""


class Oauth2ClientsListResponseTypedDict(TypedDict):
    result: ListResourceOAuth2ClientTypedDict


class Oauth2ClientsListResponse(BaseModel):
    next: Callable[[], Optional[Oauth2ClientsListResponse]]

    result: ListResourceOAuth2Client
