"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productpriceonetimecustom import (
    ProductPriceOneTimeCustom,
    ProductPriceOneTimeCustomTypedDict,
)
from .productpriceonetimefixed import (
    ProductPriceOneTimeFixed,
    ProductPriceOneTimeFixedTypedDict,
)
from .productpriceonetimefree import (
    ProductPriceOneTimeFree,
    ProductPriceOneTimeFreeTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


ProductPriceOneTimeTypedDict = TypeAliasType(
    "ProductPriceOneTimeTypedDict",
    Union[
        ProductPriceOneTimeFreeTypedDict,
        ProductPriceOneTimeFixedTypedDict,
        ProductPriceOneTimeCustomTypedDict,
    ],
)


ProductPriceOneTime = TypeAliasType(
    "ProductPriceOneTime",
    Union[ProductPriceOneTimeFree, ProductPriceOneTimeFixed, ProductPriceOneTimeCustom],
)
